#!/bin/bash
#
#   INSTALL.sh   : Installation for FJSVfefpcl RHEL7 (PRIMEQUEST3000)
#   version      : 6.0.0
#   author       : K Kato
#
#   Copyright FUJITSU LIMITED 2017
#
#**************************************************************************
LANG=C; export LANG
LC_ALL=C; export LC_ALL

#-------------------------------------------------------------------------
# Environment definition
#-------------------------------------------------------------------------
DIRNAME="/usr/bin/dirname"
BASENAME="/bin/basename"
UNAME="/bin/uname"
GREP="/bin/grep"
FIND="/usr/bin/find"
SED="/bin/sed"
RPM="/bin/rpm"
AWK="/bin/awk"
DMIDECODE="/usr/sbin/dmidecode"
CHECKHSSC="/opt/FJSVossn-checkhssc/bin/checkhssc"

BASEDIR=$(cd `$DIRNAME $0` && /bin/pwd)
SHNAME=`$BASENAME $0`

UNAMEM="`$UNAME -m`"

IDXCOM=0
IDXDEF=1
IDKDMP=2
IDPDEF=3
IDPCOM=4
IDCKHS=5

MSGLOG="/tmp/postsetup.log"
MSGID="FJSVfefpcl"

#-------------------------------------------------------------------------
# sub routine
#-------------------------------------------------------------------------
logmsg() {
    echo "$*" | tee -a $MSGLOG
}


#-------------------------------------------------------------------------
# main routine
#-------------------------------------------------------------------------
#
# su ?
#
if [ $EUID != 0 ]; then
#    logmsg "$SHNAME: not privileged."
    exit 1
fi

#
# Machine-type check
#

if [ ! -e "$DMIDECODE" ];then
        logmsg "$MSGID: Command dmidecode not found."
        logmsg "$MSGID: install failed."
        exit 1;
fi

MACHINE_NAME=$($DMIDECODE -t 1 | $AWK -F: '$1 ~ /Product Name$/ { print substr($2, match($2, /[[:alpha:]]/))}')

case $MACHINE_NAME in
        PRIMEQUEST*)
                ;;
        *)
                logmsg "$MSGID: Server type is not PRIMEQUEST, install canceled."
                logmsg "$MSGID: install completed."
                exit 0
                ;;
esac

#
# check argument
#
case $# in
  0)
    ;;
  *)
    logmsg "$MSGID: Illegal option."
    logmsg "$MSGID: Usage: $SHNAME"
    exit 1
    ;;
esac


#
# check rpm files
#
if [ $UNAMEM != "x86_64" ]; then
    logmsg "$MSGID: $UNAMEM is not supported."
    logmsg "$MSGID: install failed."
    exit 1
fi
for ent in $($FIND $BASEDIR | $GREP "\.$UNAMEM\."); do
    $BASENAME $ent | $GREP "\-kmod-common-" > /dev/null 2>&1
    if [ $? -eq 0 ]; then
        COMM_FP="`echo $ent | $GREP "\-kmod-common-"`"
        continue;
    fi
    $BASENAME $ent | $GREP "\kmod-FJSVossn-" > /dev/null 2>&1
    if [ $? -eq 0 ]; then
        KMODDEF_PA="`echo $ent | $GREP "\kmod-FJSVossn-"`"
        continue;
    fi
    $BASENAME $ent | $GREP "\kmod-FJSVfefpcl-" > /dev/null 2>&1
    if [ $? -eq 0 ]; then
        KMODDEF_FP="`echo $ent | $GREP "\kmod-FJSVfefpcl-"`"
        continue;
    fi
    $BASENAME $ent | $GREP "\FJSVkdump-" > /dev/null 2>&1
    if [ $? -eq 0 ]; then
        KDUMP_RP="`echo $ent | $GREP "\FJSVkdump-"`"
        continue;
    fi
    $BASENAME $ent | $GREP "\FJSVossn-checkhssc" > /dev/null 2>&1
    if [ $? -eq 0 ]; then
        CHKHSSC="`echo $ent | $GREP "\FJSVossn-checkhssc-"`"
        continue;
    fi
    # default(Intel64) or PAE(x86)
    COMM_PA="`echo $ent`"
done

FPRPM=($COMM_FP $KMODDEF_FP $KDUMP_RP $KMODDEF_PA $COMM_PA $CHKHSSC)
NMRPM=()
NMVL=()
NMPKG=()
for idx in $IDXCOM $IDXDEF $IDKDMP $IDPDEF $IDPCOM $IDCKHS ; do
    NMRPM=(${NMRPM[@]} `$BASENAME ${FPRPM[$idx]}`)
    NMVL=(${NMVL[@]} `echo ${NMRPM[$idx]} | $SED -n "s/\.[^\.]*\.rpm$//p"`)
    NMPKG=(${NMPKG[@]} `$RPM -qp --qf '%{NAME}\n' ${FPRPM[$idx]}`)
done


#
# if older version and necessary-to-be-replaced one is installed, 
# remove old one.
#
INSTALLED=(0 0 0 0 0 0)
for idx in $IDXCOM $IDXDEF $IDPDEF $IDPCOM $IDCKHS ; do
    $RPM -q ${NMPKG[$idx]} > /dev/null 2>&1
    if [ $? -eq 0 ]; then
        INSTALLED[$idx]=1
        $RPM -Uvh --test --nodeps ${FPRPM[$idx]} > /dev/null 2>&1
        if [ $? -eq 0 ]; then
            INSTALLED[$idx]=2
        fi
    fi
done


if [ ${INSTALLED[$IDXCOM]} -ge 1 -o ${INSTALLED[$IDXDEF]} -ge 1 -o ${INSTALLED[$IDPDEF]} -ge 1 -o ${INSTALLED[$IDPCOM]} -ge 1  -o ${INSTALLED[$IDCKHS]} -ge 1 ]; then
    if [ ${INSTALLED[$IDXCOM]} -eq 1 -a ${INSTALLED[$IDXDEF]} -eq 1 -a ${INSTALLED[$IDPDEF]} -eq 1 -a ${INSTALLED[$IDPCOM]} -eq 1 -a ${INSTALLED[$IDCKHS]} -eq 1 ]; then
        logmsg "$MSGID: The same or newer version one is already installed, so updating skipped."
        logmsg "$MSGID: install completed."
        exit 0
    fi
    logmsg "$MSGID: Remove old package."
    $BASEDIR/UNINSTALL.sh >> $MSGLOG 2>&1
    if [ $? -ne 0 ]; then
        logmsg "$MSGID: install failed."
        exit 1
    fi
fi

# check Machine (check Get/Set Host System Status command)

for idx in $IDCKHS ; do
    $RPM -ivh ${FPRPM[$idx]} >> $MSGLOG 2>&1
    if [ $? -ne 0 ]; then
       logmsg "$MSGID: Fatal error: Cannot install ${NMRPM[$idx]}."
       logmsg "$MSGID: install failed."
       exit 1
    else
       logmsg "$MSGID: ${NMRPM[$idx]} install completed."
       $CHECKHSSC >> $MSGLOG 2>&1
      if [ $? -ne 0 ]; then
          logmsg "$MSGID: Fatal error: Server not supported IPMI(OEM) command."
          logmsg "$MSGID: install failed."
          $RPM -e ${NMPKG[$idx]} >> $MSGLOG 2>&1
          exit 1
      fi
    fi
done

# check & install FJSVkdump-post-wrapper

for idx in $IDKDMP ; do
    $RPM -q ${NMPKG[$idx]} > /dev/null 2>&1
    if [ $? -ne 0 ]; then
       $RPM -ivh ${FPRPM[$idx]} >> $MSGLOG 2>&1
       if [ $? -ne 0 ]; then
           logmsg "$MSGID: Fatal error: Cannot install ${NMRPM[$idx]}."
           logmsg "$MSGID: install failed."
           exit 1
       else
           logmsg "$MSGID: ${NMRPM[$idx]} install completed."
       fi
    fi
done

#
# install package
#

for idx in $IDXCOM $IDXDEF $IDPDEF $IDPCOM ; do
    $RPM -ivh ${FPRPM[$idx]} >> $MSGLOG 2>&1
    if [ $? -ne 0 ]; then
        logmsg "$MSGID: Fatal error: Cannot install ${NMRPM[$idx]}."
        logmsg "$MSGID: install failed."
        exit 1
    else
        logmsg "$MSGID: ${NMRPM[$idx]} install completed."
    fi
done

logmsg "$MSGID: install completed."
exit 0
