#!/bin/bash
#
#   UNINSTALL.sh : Uninstallation for FJSVfefpcl RHEL7 (PRIMEQUEST3000)
#   version      : 6.0.0
#   author       : K Kato
#
#   Copyright FUJITSU LIMITED 2017
#
#**************************************************************************
LANG=C; export LANG
LC_ALL=C; export LC_ALL

#-------------------------------------------------------------------------
# Environment definition
#-------------------------------------------------------------------------
DIRNAME="/usr/bin/dirname"
BASENAME="/bin/basename"
UNAME="/bin/uname"
GREP="/bin/grep"
FIND="/usr/bin/find"
SED="/bin/sed"
RPM="/bin/rpm"

BASEDIR=$(cd `$DIRNAME $0` && /bin/pwd)
SHNAME=`$BASENAME $0`

UNAMEM="`$UNAME -m`"

IDXCOM=0
IDXDEF=1
IDKDMP=2
IDPDEF=3
IDPCOM=4
IDCKHS=5

MSGLOG="/tmp/postsetup.log"
MSGID="FJSVfefpcl"

#-------------------------------------------------------------------------
# sub routine
#-------------------------------------------------------------------------
logmsg() {
#    echo "$*" >> $MSGLOG
    echo "$*"
}


#-------------------------------------------------------------------------
# main routine
#-------------------------------------------------------------------------
#
# su ?
#
if [ $EUID != 0 ]; then
    logmsg "$SHNAME: not privileged."
    exit 1
fi


#
# check argument
#
case $# in
  0)
    ;;
  *)
    logmsg "$MSGID: Illegal option."
    logmsg "$MSGID: Usage: $SHNAME"
    exit 1
    ;;
esac


#
# check rpm files
#
if [ $UNAMEM != "x86_64" ]; then
    logmsg "$MSGID: $UNAMEM is not supported."
    logmsg "$MSGID: uninstall failed."
    exit 1
fi
for ent in $($FIND $BASEDIR | $GREP "\.$UNAMEM\."); do
    $BASENAME $ent | $GREP "\-kmod-common-" > /dev/null 2>&1
    if [ $? -eq 0 ]; then
        COMM_FP="`echo $ent | $GREP "\-kmod-common-"`"
        continue;
    fi
    $BASENAME $ent | $GREP "\kmod-FJSVossn-" > /dev/null 2>&1
    if [ $? -eq 0 ]; then
        KMODDEF_PA="`echo $ent | $GREP "\kmod-FJSVossn-"`"
        continue;
    fi
    $BASENAME $ent | $GREP "\kmod-FJSVfefpcl-" > /dev/null 2>&1
    if [ $? -eq 0 ]; then
        KMODDEF_FP="`echo $ent | $GREP "\kmod-FJSVfefpcl-"`"
        continue;
    fi
    $BASENAME $ent | $GREP "\FJSVkdump-" > /dev/null 2>&1
    if [ $? -eq 0 ]; then
        KDUMP_RP="`echo $ent | $GREP "\FJSVkdump-"`"
        continue;
    fi
    $BASENAME $ent | $GREP "\FJSVossn-checkhssc-" > /dev/null 2>&1
    if [ $? -eq 0 ]; then
        CHKSSC="`echo $ent | $GREP "\FJSVossn-checkhssc-"`"
        continue;
    fi
    # default(Intel64) or PAE(x86)
    COMM_PA="`echo $ent`"
done

FPRPM=($COMM_FP $KMODDEF_FP $KDUMP_RP $KMODDEF_PA $COMM_PA $CHKSSC)
NMRPM=()
NMVL=()
NMPKG=()
for idx in $IDXCOM $IDXDEF $IDKDMP $IDPDEF $IDPCOM $IDCKHS; do
    NMRPM=(${NMRPM[@]} `$BASENAME ${FPRPM[$idx]}`)
    NMVL=(${NMVL[@]} `echo ${NMRPM[$idx]} | $SED -n "s/\.[^\.]*\.rpm$//p"`)
    NMPKG=(${NMPKG[@]} `$RPM -qp --qf '%{NAME}\n' ${FPRPM[$idx]}`)
done


#
# uninstall package
#
RET=0
for idx in $IDPCOM $IDPDEF $IDXDEF $IDXCOM $IDCKHS; do
    $RPM -q ${NMPKG[$idx]} > /dev/null 2>&1
    if [ $? -eq 0 ]; then
        logmsg "$MSGID: $RPM -e --nodeps ${NMPKG[$idx]}"
        $RPM -e --nodeps ${NMPKG[$idx]} 2>&1
        if [ $? -ne 0 ]; then
            logmsg "$MSGID: Fatal error: Cannot uninstall ${NMPKG[$idx]}."
            RET=1
        fi
    fi
done

# check & uninstall FJSVkdump-post-wrapper
for idx in $IDKDMP ; do
    $RPM -q --whatrequires ${NMPKG[$idx]} > /dev/null 2>&1
    if [ $? -ne 0 ]; then
        logmsg "$MSGID: $RPM -e --nodeps ${NMPKG[$idx]}"
        $RPM -e --nodeps ${NMPKG[$idx]} 2>&1
        if [ $? -ne 0 ]; then
            logmsg "$MSGID: Fatal error: Cannot uninstall ${NMPKG[$idx]}."
            RET=1
        fi
    fi
done

if [ $RET -eq 0 ]; then
    logmsg "$MSGID: uninstall completed."
    exit 0
else
    logmsg "$MSGID: uninstall failed."
    exit 1
fi
