#! /bin/bash

if ! hash ipmitool 2>/dev/null; then
    echo "Please install ipmitool" >&2
    exit 2
fi

# Device ID
# [3:0] Chip ID:
#       0: Kalypso
#       1: iRMCS1
#       2: iRMCS2
#       3: iRMCS3 (Pilot-3 with ThreadX FW)
#       4: iRMCS4 (Pilot-3 with Linux FW)
#       5: iRMCS5 (Pilot-4 with Linux FW)
DEVICE_ID_CHIP_ID_BITS=4
DEVICE_ID_CHIP_ID_MASK="$(((1 << DEVICE_ID_CHIP_ID_BITS) - 1))"
CHIP_ID_KALYPSO=0
CHIP_ID_IRMC1=1
CHIP_ID_IRMC2=2
CHIP_ID_IRMC3=3
CHIP_ID_IRMC4=4
CHIP_ID_IRMC5=5

function get_device_id () {
    re='^Device ID[ ]+:[ ]+([0-9]+)'
    LANG=C ipmitool mc info 2>/dev/null | {
        while read -r LINE; do
            if [[ $LINE =~ $re ]]; then
                echo ${BASH_REMATCH[1]}
                return
            fi
        done;
        echo failed;
    }
}
DEVICE_ID=$(get_device_id)
if [[ $DEVICE_ID == "failed" ]]; then
    echo "Failed to get Device ID" >&2
    exit 2
fi

CHIP_ID=$((DEVICE_ID & DEVICE_ID_CHIP_ID_MASK))

if [[ $CHIP_ID == $CHIP_ID_IRMC5 || $CHIP_ID > $CHIP_ID_IRMC5 ]]; then
    retval=0
else
    retval=1
fi

exit $retval
